@@ -7,11 +7,13 @@ require Exporter;
 *import = \&Exporter::import;
 @EXPORT_OK=qw(dump pp);
 
-$VERSION = "1.02";  # $Date: 2003/12/18 09:27:35 $
+$VERSION = "1.03";  # $Date: 2004/04/13 12:59:07 $
 $DEBUG = 0;
 
 use overload ();
-use vars qw(%seen %refcnt @dump @fixup %require);
+use vars qw(%seen %refcnt @dump @fixup %require $TRY_BASE64);
+
+$TRY_BASE64 = 50 unless defined $TRY_BASE64;
 
 my %is_perl_keyword = map { $_ => 1 }
 qw( __FILE__ __LINE__ __PACKAGE__ __DATA__ __END__ AUTOLOAD BEGIN CORE
@@ -393,28 +395,30 @@ sub quote {
   s/([\a\b\t\n\f\r\e])/$esc{$1}/g;
 
   # no need for 3 digits in escape for these
-  s/([\0-\037])(?!\d)/'\\'.sprintf('%o',ord($1))/eg;
+  s/([\0-\037])(?!\d)/sprintf('\\%o',ord($1))/eg;
 
   if ($high) {
-      s/([\0-\037\177])/'\\'.sprintf('%03o',ord($1))/eg;
+      s/([\0-\037\177])/sprintf('\\%03o',ord($1))/eg;
       if ($high eq "iso8859") {
-          s/[\200-\240]/'\\'.sprintf('%o',ord($1))/eg;
+          s/[\200-\240]/sprintf('\\%o',ord($1))/eg;
       } elsif ($high eq "utf8") {
 #         use utf8;
 #         $str =~ s/([^\040-\176])/sprintf "\\x{%04x}", ord($1)/ge;
       }
   } else {
-      s/([\0-\037\177-\377])/'\\'.sprintf('%03o',ord($1))/eg;
+      s/([\0-\037\177-\377])/sprintf('\\x%02X',ord($1))/eg;
+      s/([^\040-\176])/sprintf('\\x{%X}',ord($1))/eg;
   }
 
-  if (length($_) > 40  && length($_) > (length($_[0]) * 2)) {
-      # too much binary data, better to represent as a hex string?
+  if (length($_) > 40  && !/\\x\{/ && length($_) > (length($_[0]) * 2)) {
+      # too much binary data, better to represent as a hex/base64 string
 
       # Base64 is more compact than hex when string is longer than
       # 17 bytes (not counting any require statement needed).
       # But on the other hand, hex is much more readable.
-      if (length($_[0]) > 50 && eval { require MIME::Base64 }) {
-	  # XXX Perhaps we should just use unpack("u",...) instead.
+      if ($TRY_BASE64 && length($_[0]) > $TRY_BASE64 &&
+	  eval { require MIME::Base64 })
+      {
 	  $require{"MIME::Base64"}++;
 	  return "MIME::Base64::decode(\"" .
 	             MIME::Base64::encode($_[0],"") .
@@ -478,7 +482,7 @@ L<Data::Dumper>, L<Storable>
 The C<Data::Dump> module is written by Gisle Aas <gisle@aas.no>, based
 on C<Data::Dumper> by Gurusamy Sarathy <gsar@umich.edu>.
 
- Copyright 1998-2000,2003 Gisle Aas.
+ Copyright 1998-2000,2003-2004 Gisle Aas.
  Copyright 1996-1998 Gurusamy Sarathy.
 
 This library is free software; you can redistribute it and/or
